summaryrefslogtreecommitdiff
path: root/src/road_func.h
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2008-09-30 20:39:50 +0000
committerrubidium <rubidium@openttd.org>2008-09-30 20:39:50 +0000
commit3b798599b63067c2e92aa49906ea66a07ae8de44 (patch)
tree69fb7ae1d9bdadb9e7386cb70b0a26621ad9b57f /src/road_func.h
parentcc1e761edab14f8264dba44d09f7272d931bdd93 (diff)
downloadopenttd-3b798599b63067c2e92aa49906ea66a07ae8de44.tar.xz
(svn r14421) -Codechange: rename all player variables/types to company *or* client so it is immediatelly clear which one you are working with.
Diffstat (limited to 'src/road_func.h')
-rw-r--r--src/road_func.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/road_func.h b/src/road_func.h
index c0baeee3f..264bc21f4 100644
--- a/src/road_func.h
+++ b/src/road_func.h
@@ -140,26 +140,26 @@ static inline RoadBits AxisToRoadBits(Axis a)
}
/**
* Finds out, whether given player has all given RoadTypes available
* @param PlayerID ID of player
* @param rts RoadTypes to test
* @return true if player has all requested RoadTypes available
*/
-bool HasRoadTypesAvail(const PlayerID p, const RoadTypes rts);
+bool HasRoadTypesAvail(const CompanyID company, const RoadTypes rts);
/**
* Validate functions for rail building.
* @param rt road type to check.
* @return true if the current player may build the road.
*/
bool ValParamRoadType(const RoadType rt);
/**
* Get the road types the given player can build.
* @param p the player to get the roadtypes for.
* @return the road types.
*/
-RoadTypes GetPlayerRoadtypes(const PlayerID p);
+RoadTypes GetCompanyRoadtypes(const CompanyID company);
void UpdateLevelCrossing(TileIndex tile, bool sound = true);
@@ -140,26 +140,26 @@ static inline RoadBits AxisToRoadBits(Axis a)
}
/**
- * Finds out, whether given player has all given RoadTypes available
- * @param PlayerID ID of player
+ * Finds out, whether given company has all given RoadTypes available
+ * @param company ID of company
* @param rts RoadTypes to test
@@ -140,26 +140,26 @@ static inline RoadBits AxisToRoadBits(Axis a)
* @param rts RoadTypes to test
- * @return true if player has all requested RoadTypes available
+ * @return true if company has all requested RoadTypes available
*/
@@ -140,26 +140,26 @@ static inline RoadBits AxisToRoadBits(Axis a)
* Validate functions for rail building.
* @param rt road type to check.
- * @return true if the current player may build the road.
+ * @return true if the current company may build the road.
*/
bool ValParamRoadType(const RoadType rt);
@@ -140,26 +140,26 @@ static inline RoadBits AxisToRoadBits(Axis a)
bool ValParamRoadType(const RoadType rt);
/**
- * Get the road types the given player can build.
- * @param p the player to get the roadtypes for.
+ * Get the road types the given company can build.
+ * @param company the company to get the roadtypes for.
* @return the road types.
*/